/*
 * IBM Confidential
 * OCO Source Materials
 * Rational ClearCase
 * (C) Copyright IBM Corporation. 2013.  All rights reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 */
package com.ibm.rational.wvcm.stp.cc;

import javax.wvcm.WvcmException;

/**
 * Handler for remote view agent callback operations.
 */
public interface CcRemoteViewAgentCallback {
    
    /**
     * Event to indicate a remote view agent has connected
     */
    public interface ConnectEvent {
        /**
         * Answers with the remote view agent's provider
         * @return Provider for this view
         */
        CcProvider getProvider();
        
        /**
         * Answers with the view tag of the connected view
         * @return the view tag
         */
        String getViewTag();
        
        /**
         * Answers with the uuid of the connected view
         * @return A dense representation of the uuid as a string. 
         */
        String getViewUuid();
        
        /**
         * Answers with an error, or null if successful.
         * @return a WvcmException, or null if no errors
         */
        WvcmException getError();
    }
    
    /**
     * Event to indicate a remote view agent has disconnected
     */
    public interface DisconnectEvent {
        /**
         * Answers with the remote view agent's provider
         * @return Provider for this view
         */
        CcProvider getProvider();
        
        /**
         * Answers with the view tag for the disconnected view
         * @return the view tag
         */
        String getViewTag();
        
        /**
         * Answers with the uuid of the connected view
         * @return A dense representation of the uuid as a string. 
         */
        String getViewUuid();
        
        /**
         * Answers with an error,or null if successful.
         * @return a WvcmException, or null if no errors
         */
        WvcmException getError();
    }
    
    /**
     * Handle a remote view agent connection event.
     * @param event the connect event
     */
    void handleConnect(ConnectEvent event);
    
    /**
     * Handle a remote view agent disconnect event
     * @param event the disconnect event
     */
    void handleDisconnect(DisconnectEvent event);
}
